@@ -67,7 +67,7 @@ static AST *left_recursive_deep(AST *ast_)
  * \param fodder The fodder to print
  * \param space_before Whether a space should be printed before any other output.
  * \param separate_token If the last fodder was an interstitial, whether a space should follow it.
- * \param final Whether fodder is the last one in 
+ * \param final Whether fodder is the last one in
  */
 void fodder_fill(std::ostream &o, const Fodder &fodder, bool space_before, bool separate_token, bool final)
 {
@@ -414,6 +414,10 @@ class Unparser {
             o << "importstr";
             unparse(ast->file, true);
 
+        } else if (auto *ast = dynamic_cast<const Importbin *>(ast_)) {
+            o << "importbin";
+            unparse(ast->file, true);
+
         } else if (auto *ast = dynamic_cast<const InSuper *>(ast_)) {
             unparse(ast->element, true);
             fill(ast->inFodder, true, true);
@@ -1784,6 +1788,11 @@ class FixIndentation {
             Indent new_indent = newIndent(open_fodder(ast->file), indent, column + 1);
             expr(ast->file, new_indent, true);
 
+        } else if (auto *ast = dynamic_cast<Importbin *>(ast_)) {
+            column += 9;  // importbin
+            Indent new_indent = newIndent(open_fodder(ast->file), indent, column + 1);
+            expr(ast->file, new_indent, true);
+
         } else if (auto *ast = dynamic_cast<InSuper *>(ast_)) {
             expr(ast->element, indent, space_before);
             fill(ast->inFodder, true, true, indent.lineUp);
